PhilipsEngine

Struct PhilipsEngine 

pub struct PhilipsEngine { /* private fields */ }

Implementations

Source

impl PhilipsEngine

pub fn new() -> Self

Create a new instance of PhilipsEngine

pub fn facade<P: AsRef<Path>>( &self, filename: P, container: &ContainerName, ) -> Result<Facade<'_>>

Create a new instance of Facade A Facade is a reference to a Philips Engine internal object This facade is a handle to a file May fail if the fail cannot be opened

pub fn facade_with_cache_file<P: AsRef<Path>, R: AsRef<Path>>( &self, filename: P, container: &ContainerName, cache_filename: R, ) -> Result<Facade<'_>>

Create a new instance of Facade A Facade is a reference to a Philips Engine internal object This facade is a handle to a file May fail if the fail cannot be opened

pub fn sdk_version(&self) -> Result<String>

Returns the SDK PixelEngine version

pub fn containers(&self) -> impl Iterator<Item = &str>

Returns all containers supported by the SDK PixelEngine

pub fn container_version(&self, container: &str) -> Result<&str>

Returns the version of a container

pub fn compressors(&self) -> impl Iterator<Item = &str>

Returns all compressors supported by the SDK PixelEngine

pub fn pixel_transforms(&self) -> impl Iterator<Item = &str>

Returns all pixel_transforms supported by the SDK PixelEngine

pub fn colorspace_transforms(&self) -> impl Iterator<Item = &str>

Returns all colorspace_transforms supported by the SDK PixelEngine

pub fn quality_presets(&self) -> impl Iterator<Item = &str>

Returns all quality_presets supported by the SDK PixelEngine

pub fn supported_filters(&self) -> impl Iterator<Item = &str>

Returns all supported_filters supported by the SDK PixelEngine filters can be added to the pipeline using addFilter