pub struct PhilipsEngine { /* private fields */ }Implementations
Sourceimpl PhilipsEngine
impl PhilipsEngine
Sourcepub fn facade<P: AsRef<Path>>(
&self,
filename: P,
container: &ContainerName,
) -> Result<Facade<'_>>
pub fn facade<P: AsRef<Path>>( &self, filename: P, container: &ContainerName, ) -> Result<Facade<'_>>
Create a new instance of Facade A Facade is a reference to a Philips Engine internal object This facade is a handle to a file May fail if the fail cannot be opened
Sourcepub fn facade_with_cache_file<P: AsRef<Path>, R: AsRef<Path>>(
&self,
filename: P,
container: &ContainerName,
cache_filename: R,
) -> Result<Facade<'_>>
pub fn facade_with_cache_file<P: AsRef<Path>, R: AsRef<Path>>( &self, filename: P, container: &ContainerName, cache_filename: R, ) -> Result<Facade<'_>>
Create a new instance of Facade A Facade is a reference to a Philips Engine internal object This facade is a handle to a file May fail if the fail cannot be opened
Sourcepub fn sdk_version(&self) -> Result<String>
pub fn sdk_version(&self) -> Result<String>
Returns the SDK PixelEngine version
Sourcepub fn containers(&self) -> impl Iterator<Item = &str>
pub fn containers(&self) -> impl Iterator<Item = &str>
Returns all containers supported by the SDK PixelEngine
Sourcepub fn container_version(&self, container: &str) -> Result<&str>
pub fn container_version(&self, container: &str) -> Result<&str>
Returns the version of a container
Sourcepub fn compressors(&self) -> impl Iterator<Item = &str>
pub fn compressors(&self) -> impl Iterator<Item = &str>
Returns all compressors supported by the SDK PixelEngine
Sourcepub fn pixel_transforms(&self) -> impl Iterator<Item = &str>
pub fn pixel_transforms(&self) -> impl Iterator<Item = &str>
Returns all pixel_transforms supported by the SDK PixelEngine
Sourcepub fn colorspace_transforms(&self) -> impl Iterator<Item = &str>
pub fn colorspace_transforms(&self) -> impl Iterator<Item = &str>
Returns all colorspace_transforms supported by the SDK PixelEngine
Sourcepub fn quality_presets(&self) -> impl Iterator<Item = &str>
pub fn quality_presets(&self) -> impl Iterator<Item = &str>
Returns all quality_presets supported by the SDK PixelEngine
Sourcepub fn supported_filters(&self) -> impl Iterator<Item = &str>
pub fn supported_filters(&self) -> impl Iterator<Item = &str>
Returns all supported_filters supported by the SDK PixelEngine filters can be added to the pipeline using addFilter